@@ -64,6 +64,7 @@ insert into perm_server_group (server_id, id1, id2, perm_id, perm_value, perm_ne
  ( 0, 2, 0, "b_channel_create_with_maxfamilyclients", 1, 0, 0 ),
  ( 0, 2, 0, "b_channel_create_with_needed_talk_power", 1, 0, 0 ),
  ( 0, 2, 0, "b_channel_create_with_password", 1, 0, 0 ),
+ ( 0, 2, 0, "b_channel_create_with_banner", 1, 0, 0 ),
  ( 0, 2, 0, "b_channel_create_with_sortorder", 1, 0, 0 ),
  ( 0, 2, 0, "b_channel_create_with_topic", 1, 0, 0 ),
  ( 0, 2, 0, "b_channel_delete_flag_force", 1, 0, 0 ),
@@ -91,6 +92,7 @@ insert into perm_server_group (server_id, id1, id2, perm_id, perm_value, perm_ne
  ( 0, 2, 0, "b_channel_modify_needed_talk_power", 1, 0, 0 ),
  ( 0, 2, 0, "b_channel_modify_parent", 1, 0, 0 ),
  ( 0, 2, 0, "b_channel_modify_password", 1, 0, 0 ),
+ ( 0, 2, 0, "b_channel_modify_banner", 1, 0, 0 ),
  ( 0, 2, 0, "b_channel_modify_sortorder", 1, 0, 0 ),
  ( 0, 2, 0, "b_channel_modify_temp_delete_delay", 1, 0, 0 ),
  ( 0, 2, 0, "b_channel_modify_topic", 1, 0, 0 ),
@@ -285,6 +287,7 @@ insert into perm_server_group (server_id, id1, id2, perm_id, perm_value, perm_ne
  ( 0, 2, 0, "i_needed_modify_power_channel_create_with_maxfamilyclients", 100, 0, 0 ),
  ( 0, 2, 0, "i_needed_modify_power_channel_create_with_needed_talk_power", 100, 0, 0 ),
  ( 0, 2, 0, "i_needed_modify_power_channel_create_with_password", 100, 0, 0 ),
+ ( 0, 2, 0, "i_needed_modify_power_channel_create_with_banner", 100, 0, 0 ),
  ( 0, 2, 0, "i_needed_modify_power_channel_create_with_sortorder", 100, 0, 0 ),
  ( 0, 2, 0, "i_needed_modify_power_channel_create_with_topic", 100, 0, 0 ),
  ( 0, 2, 0, "i_needed_modify_power_channel_delete_flag_force", 100, 0, 0 ),
@@ -318,6 +321,7 @@ insert into perm_server_group (server_id, id1, id2, perm_id, perm_value, perm_ne
  ( 0, 2, 0, "i_needed_modify_power_channel_modify_needed_talk_power", 100, 0, 0 ),
  ( 0, 2, 0, "i_needed_modify_power_channel_modify_parent", 100, 0, 0 ),
  ( 0, 2, 0, "i_needed_modify_power_channel_modify_password", 100, 0, 0 ),
+ ( 0, 2, 0, "i_needed_modify_power_channel_modify_banner", 100, 0, 0 ),
  ( 0, 2, 0, "i_needed_modify_power_channel_modify_power", 100, 0, 0 ),
  ( 0, 2, 0, "i_needed_modify_power_channel_modify_sortorder", 100, 0, 0 ),
  ( 0, 2, 0, "i_needed_modify_power_channel_modify_temp_delete_delay", 100, 0, 0 ),
@@ -525,7 +529,8 @@ insert into perm_server_group (server_id, id1, id2, perm_id, perm_value, perm_ne
  ( 0, 3, 0, "b_channel_create_with_maxclients", 1, 0, 0 ),
  ( 0, 3, 0, "b_channel_create_with_maxfamilyclients", 1, 0, 0 ),
  ( 0, 3, 0, "b_channel_create_with_needed_talk_power", 1, 0, 0 ),
- ( 0, 3, 0, "b_channel_create_with_password", 1, 0, 0 );
+ ( 0, 3, 0, "b_channel_create_with_password", 1, 0, 0 ),
+ ( 0, 3, 0, "b_channel_create_with_banner", 1, 0, 0 );
  --sqlite limits inserts to 500 per statement;
 insert into perm_server_group (server_id, id1, id2, perm_id, perm_value, perm_negated, perm_skip) values
  ( 0, 3, 0, "b_channel_create_with_sortorder", 1, 0, 0 ),
@@ -555,6 +560,7 @@ insert into perm_server_group (server_id, id1, id2, perm_id, perm_value, perm_ne
  ( 0, 3, 0, "b_channel_modify_needed_talk_power", 1, 0, 0 ),
  ( 0, 3, 0, "b_channel_modify_parent", 1, 0, 0 ),
  ( 0, 3, 0, "b_channel_modify_password", 1, 0, 0 ),
+ ( 0, 3, 0, "b_channel_modify_banner", 1, 0, 0 ),
  ( 0, 3, 0, "b_channel_modify_sortorder", 1, 0, 0 ),
  ( 0, 3, 0, "b_channel_modify_temp_delete_delay", 1, 0, 0 ),
  ( 0, 3, 0, "b_channel_modify_topic", 1, 0, 0 ),
@@ -721,6 +727,7 @@ insert into perm_server_group (server_id, id1, id2, perm_id, perm_value, perm_ne
  ( 0, 3, 0, "i_needed_modify_power_channel_create_with_maxfamilyclients", 75, 0, 0 ),
  ( 0, 3, 0, "i_needed_modify_power_channel_create_with_needed_talk_power", 75, 0, 0 ),
  ( 0, 3, 0, "i_needed_modify_power_channel_create_with_password", 75, 0, 0 ),
+ ( 0, 3, 0, "i_needed_modify_power_channel_create_with_banner", 75, 0, 0 ),
  ( 0, 3, 0, "i_needed_modify_power_channel_create_with_sortorder", 75, 0, 0 ),
  ( 0, 3, 0, "i_needed_modify_power_channel_create_with_topic", 75, 0, 0 ),
  ( 0, 3, 0, "i_needed_modify_power_channel_delete_flag_force", 75, 0, 0 ),
@@ -754,6 +761,7 @@ insert into perm_server_group (server_id, id1, id2, perm_id, perm_value, perm_ne
  ( 0, 3, 0, "i_needed_modify_power_channel_modify_needed_talk_power", 75, 0, 0 ),
  ( 0, 3, 0, "i_needed_modify_power_channel_modify_parent", 75, 0, 0 ),
  ( 0, 3, 0, "i_needed_modify_power_channel_modify_password", 75, 0, 0 ),
+ ( 0, 3, 0, "i_needed_modify_power_channel_modify_banner", 75, 0, 0 ),
  ( 0, 3, 0, "i_needed_modify_power_channel_modify_power", 75, 0, 0 ),
  ( 0, 3, 0, "i_needed_modify_power_channel_modify_sortorder", 75, 0, 0 ),
  ( 0, 3, 0, "i_needed_modify_power_channel_modify_temp_delete_delay", 75, 0, 0 ),
